from setuptools import setup

setup(
    name='pontryax',
    version='0.0.1',
    py_modules=['pontryax'],
    # description='',
    author='Muchen Sun',
    author_email='sunmch15@gmail.com',
    # url='',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
    ],
    python_requires='>=3.6',
)